_**by Edgar Allan Poe**  
(published 1838)_

    

_"Ours is a world of words: Quiet we call    
Silence -- which is the merest word of all"  
                                     -Al Aaraaf._  
  
    "Listen to me," said the Demon, as he placed his hand upon my head. "There is a spot upon this accursed earth which thou hast never yet beheld And if by any chance thou hast beheld it, it must have been in one of those vigorous dreams which come like the Simoon upon the brain of the sleeper who hath lain down to sleep among the forbidden sunbeams --among the sunbeams, I say, which slide from off the solemn columns of the melancholy temples in the wilderness. The region of which I speak is a dreary region in Libya, by the borders of the river Zaire. And there is no quiet there, nor silence.  
  
    "The waters of the river have a saffron and sickly hue --and they flow not onwards to the sea, but palpitate forever and forever beneath the red eye of the sun with a tumultuous and convulsive motion. For many miles on either side of the river's oozy bed is a pale desert of gigantic water-lilies. They sigh one unto the other in that solitude, and stretch towards the heaven their long ghastly necks, and nod to and fro their everlasting heads. And there is an indistinct murmur which cometh out from among them like the rushing of subterrene water. And they sigh one unto the other.  
  
    "But there is a boundary to their realm --the boundary of the dark, horrible, lofty forest. There, like the waves about the Hebrides, the low underwood is agitated continually. But there is no wind throughout the heaven. And the tall primeval trees rock eternally hither and thither with a crashing and mighty sound. And from their high summits, one by one, drop everlasting dews. And at the roots strange poisonous flowers lie writhing in perturbed slumber. And overhead, with a rustling and loud noise, the grey clouds rush westwardly forever, until they roll, a cataract, over the fiery wall of the horizon. But there is no wind throughout the heaven. And by the shores of the river Zaire there is neither quiet nor silence.  
  
    "It was night, and the rain fell; and, falling, it was rain, but, having fallen, it was blood. And I stood in the morass among the tall lilies, and the rain fell upon my head --and the lilies sighed one unto the other in the solemnity of their desolation.  
  
    "And, all at once, the moon arose through the thin ghastly mist, and was crimson in color. And mine eyes fell upon a huge grey rock which stood by the shore of the river, and was litten by the light of the moon. And the rock was grey, and ghastly, and tall, --and the rock was grey. Upon its front were characters engraven in the stone; and I walked through the morass of water-lilies, until I came close unto the shore, that I might read the characters upon the stone. But I could not decypher the characters. And I was going back into the morass, when the moon shone with a fuller red, and I turned and looked again upon the rock, and upon the characters --and the characters were DESOLATION.  
  
    "And I looked upwards, and there stood a man upon the summit of the rock, and I hid myself among the water-lilies that I might discover the actions of the man. And the man was tall and stately in form, and was wrapped up from his shoulders to his feet in the toga of old Rome. And the outlines of his figure were indistinct --but his features were the features of a Deity; for the mantle of the night, and of the mist, and of the moon, and of the dew, had left uncovered the features of his face. And his brow was lofty with thought, and his eye wild with care; and, in the few furrows upon his cheek I read the fables of sorrow, and weariness, and disgust with mankind, and a longing after solitude. And the moon shone upon his face, and upon the features of his face, and oh! they were more beautiful than the airy dreams which hovered about the souls of the daughters of Delos!  
  
    "And the man sat down upon the rock, and leaned his head upon his hand, and looked out upon the desolation. He looked down into the low unquiet shrubbery, and up into the tall primeval trees, and up higher at the rustling heaven, and into the crimson moon. And I lay close within shelter of the lilies, and observed the actions of the man. And the man trembled in the solitude --but the night waned and he sat upon the rock.  
  
    "And the man turned his attention from the heaven, and looked out upon the dreary river Zaire, and upon the yellow ghastly waters, and upon the pale legions of the water-lilies. And the man listened to the sighs of the water-lilies, and of the murmur that came up from among them. And I lay close within my covert and observed the actions of the man. And the man trembled in the solitude --but the night waned and he sat upon the rock.  
  
    "Then I went down into the recesses of the morass, and waded afar in among the wilderness of the lilies, and called unto the hippopotami which dwelt among the fens in the recesses of the morass. And the hippopotami heard my call, and came, with the behemoth, unto the foot of the rock, and roared loudly and fearfully beneath the moon. And I lay close within my covert and observed the actions of the man. And the man trembled in the solitude --but the night waned and he sat upon the rock.  
  
    "Then I cursed the elements with the curse of tumult; and a frightful tempest gathered in the heaven where before there had been no wind. And the heaven became livid with the violence of the tempest --and the rain beat upon the head of the man --and the floods of the river came down --and the river was tormented into foam --and the water-lilies shrieked within their beds --and the forest crumbled before the wind --and the thunder rolled, --and the lightning fell --and the rock rocked to its foundation. And I lay close within my covert and observed the actions of the man. And the man trembled in the solitude -- but the night waned and he sat upon the rock.  
  
    "Then I grew angry and cursed, with the curse of silence, the river, and the lilies, and the wind, and the forest, and the heaven, and the thunder, and the sighs of the water-lilies. And they became accursed and were still. And the moon ceased to totter in its pathway up the heaven --and the thunder died away --and the lightning did not flash --and the clouds hung motionless --and the waters sunk to their level and remained --and the trees ceased to rock --and the water-lilies sighed no more --and the murmur was heard no longer from among them, nor any shadow of sound throughout the vast illimitable desert. And I looked upon the characters of the rock, and they were changed --and the characters were SILENCE.  
    [[stories/William Wilson.md|William Wilson.md]]
  
    "And mine eyes fell upon the countenance of the man, and his countenance was wan with terror. And, hurriedly, he raised his head from his hand, and stood forth upon the rock, and listened. But there was no voice throughout the vast illimitable desert, and the characters upon the rock were SILENCE. And the man shuddered, and turned his face away, and fled afar off, and I beheld him no more."  
  
*      *      *      *      *      *      *      *      *      *      *  
    Now there are fine tales in the volumes of the Magi --in the iron-bound, melancholy volumes of the Magi. Therein, I say, are glorious histories of the Heaven, and of the Earth, and of the mighty Sea --and of the Genii that over-ruled the sea, and the earth, and the lofty heaven. There was much lore too in the sayings which were said by the sybils; and holy, holy things were heard of old by the dim leaves that trembled around Dodona --but, as Allah liveth, that fable which the Demon told me as he sat by my side in the shadow of the tomb, I hold to be the most wonderful of all! And as the Demon made an end of his story, he fell back within the cavity of the tomb and laughed. And I could not laugh with the Demon, and he cursed me because I could not laugh. And the lynx which dwelleth forever in the tomb, came out therefrom, and lay down at the feet of the Demon, and looked at him steadily in the face.